
/************************************************************************/
/*									*/
/*  IOShield_OledTemperature_Demo.c                                     */
/*									*/
/************************************************************************/
/*  Author: 	Bernardo Giovanni                                       */
/*  Copyright 2011, Digilent Inc. / settorezero.com        		*/
/************************************************************************/
/*
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
/************************************************************************/
/*  Module Description: 						*/
/*									*/
/*  This program reads temperature values and alarm status              */
/*  from temperature sensor TCN75A on basic I/O Shield and shows        */
/*  them on the OLED display.                                           */
/*  Values read are also sent to the serial port                        */
/*									*/
/************************************************************************/
/*  Revision History:							*/
/*									*/
/*  09/09/2011(Bernardo Giovanni): created      			*/
/*  11/09/2011(Bernardo Giovanni): prepare first release		*/
/*									*/
/************************************************************************/

#include <Wire.h>
#include <IOShieldTemp.h>
#include <IOShieldOled.h>

// Alert pin on TCN75A
#define ALERT_PIN 2
// Degree symbol in location 0
#define degree 0
// degree symbol definition
PROGMEM BYTE degreeSymbol[]={0x06,0x09,0x09,0x06,0x00,0x00,0x00,0x00};

void setup()
  {

  Serial.begin(9600); // initialize serial port
  IOShieldOled.begin(); // initialize Oled
  pinMode(ALERT_PIN, INPUT); // pin 2 as input

  // Initialize Temperature Sensor Configuration register for onshot with 11 bit resolution
  IOShieldTemp.config(IOSHIELDTEMP_ONESHOT | IOSHIELDTEMP_RES12 | IOSHIELDTEMP_ALERTHIGH);
  
  // Set the range to bring the alert pin high if it's above 78F (25.5C), alert will stay
  // high until the temp drops below 75.2F (24C).
  IOShieldTemp.setTempLimit(IOShieldTemp.convFtoC(75)); // 78.0F ~ 25.5C
  IOShieldTemp.setTempHyst(24); // 75.2F ~ 24.0C
  
  // define the degree symbol
  IOShieldOled.defineUserChar(degree, degreeSymbol);
  }

void loop() 
  {
  float tempF, tempC; // temperature values
  char sF[10], sC[10]; // strings used for display temperature values
  
  //Clear the virtual buffer
  IOShieldOled.clearBuffer();
    
  tempC = IOShieldTemp.getTemp(); // get temperature in C
  tempF = IOShieldTemp.convCtoF(tempC); // get temperature in F

  // converts float values in strings with 2 decimals
  sprintf(sC,"%0.2f",tempC);
  sprintf(sF,"%0.2f",tempF);
  
  // go to column 0, row 0
  IOShieldOled.setCursor(0, 0);
  IOShieldOled.putString("Temp: ");
  IOShieldOled.putString(sC);
  IOShieldOled.putChar(degree); // print degree symbol
  IOShieldOled.putString("C   ");
  
  // go to column 6, row 1
  IOShieldOled.setCursor(6, 1);
  IOShieldOled.putString(sF);
  IOShieldOled.putChar(degree);
  IOShieldOled.putString("F   ");

  // go to column 0, row 2
  IOShieldOled.setCursor(6, 2);
  if(digitalRead(ALERT_PIN) == HIGH)
    {
    IOShieldOled.putString("ALARM");
    }
  else
    {
    // delete ALARM string from display
    IOShieldOled.putString("     ");  
    }

  // Print temperature values also to serial port
  Serial.print(tempC);
  Serial.print(" C, ");
  Serial.print(tempF);
  Serial.print(" F");
  if(digitalRead(ALERT_PIN) == HIGH)
    Serial.print(" ALERT!");
  Serial.println();
  
  delay(1000);  
  }
